==> haskell-witherable-0.4.2-229.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-witherable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 witherable
version:              0.4.2
visibility:           public
id:                   witherable-0.4.2-8vp6m8pf3M0Augnf8mmIUp
key:                  witherable-0.4.2-8vp6m8pf3M0Augnf8mmIUp
license:              BSD-3-Clause
copyright:            Copyright (c) 2014 Fumiaki Kinoshita
maintainer:           Fumiaki Kinoshita <fumiexcel@gmail.com>
author:               Fumiaki Kinoshita
homepage:             https://github.com/fumieval/witherable
synopsis:             filterable traversable
description:
    A stronger variant of `traverse` which can remove elements and generalised mapMaybe, catMaybes, filter

category:             Data
abi:                  47a61d0b4451aeba7fbf61add33c7e49
exposed:              True
exposed-modules:      Data.Witherable Witherable
import-dirs:          /usr/lib/ghc-9.6.6/site-local/witherable-0.4.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/witherable-0.4.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/witherable-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-witherable
hs-libraries:         HSwitherable-0.4.2-8vp6m8pf3M0Augnf8mmIUp
depends:
    base-4.18.2.1 base-orphans-0.9.3-JybUSC3tjiTK5xbDkdemoL
    containers-0.6.7 hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    indexed-traversable-instances-0.1.2-Lkd5OiVpVypLKxZPidfqff
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-witherable/html/witherable.haddock
haddock-html:         /usr/share/doc/haskell-witherable/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-witherable-0.4.2-230-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-witherable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 witherable
version:              0.4.2
visibility:           public
id:                   witherable-0.4.2-FFlKR43IlesAoDsuuCtTMQ
key:                  witherable-0.4.2-FFlKR43IlesAoDsuuCtTMQ
license:              BSD-3-Clause
copyright:            Copyright (c) 2014 Fumiaki Kinoshita
maintainer:           Fumiaki Kinoshita <fumiexcel@gmail.com>
author:               Fumiaki Kinoshita
homepage:             https://github.com/fumieval/witherable
synopsis:             filterable traversable
description:
    A stronger variant of `traverse` which can remove elements and generalised mapMaybe, catMaybes, filter

category:             Data
abi:                  86e2c6a7de7924002566ca29cd194429
exposed:              True
exposed-modules:      Data.Witherable Witherable
import-dirs:          /usr/lib/ghc-9.6.6/site-local/witherable-0.4.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/witherable-0.4.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/witherable-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-witherable
hs-libraries:         HSwitherable-0.4.2-FFlKR43IlesAoDsuuCtTMQ
depends:
    base-4.18.2.1 base-orphans-0.9.3-JybUSC3tjiTK5xbDkdemoL
    containers-0.6.7 hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    indexed-traversable-instances-0.1.2-HUuqghnVr7GEAUbAb8qitO
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-witherable/html/witherable.haddock
haddock-html:         /usr/share/doc/haskell-witherable/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
